@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Play a MIDI score in real-time
 
-our $VERSION = '0.0105';
+our $VERSION = '0.0106';
 
 use strict;
 use warnings;
@@ -80,9 +80,7 @@ sub _play {
 }
 
 # This manipulates internals of MIDI::Score objects and
-# hashes used by drum-circle - doing this isn't a good
-# idea - skip to `sub play` to see the interesting piece
-# of this example.
+# hashes - doing this isn't a good idea.
 sub _reset_score {
     my ($self) = @_;
     # sorry
@@ -120,7 +118,7 @@ MIDI::RtMidi::ScorePlayer - Play a MIDI score in real-time
 
 =head1 VERSION
 
-version 0.0105
+version 0.0106
 
 =head1 SYNOPSIS
 
@@ -129,11 +127,14 @@ version 0.0105
 
   my $score = setup_score();
 
-  my %common = ( score => $score, seen => {}, etc => '...', );
+  my %common = (score => $score, seen => {}, etc => '...',);
 
   sub treble {
+      my (%args) = @_;
+      ...; # Setup things
       my $treble = sub {
-          ...; # Add notes or rests to the score
+          $args{score}->n('...');
+          ...; # See MIDI::Simple for the n() & r() methods
       };
       return $treble;
   }
@@ -144,7 +145,7 @@ version 0.0105
   MIDI::RtMidi::ScorePlayer->new(
       score    => $score, # required MIDI score object
       parts    => [ \&treble, \&bass ], # required part functions
-      common   => \%common, # optional arguments given to the part functions
+      common   => \%common, # arguments given to the part functions
       repeats  => 4, # number of repeated synched parts (default: 1)
       sleep    => 2, # number of seconds to sleep between loops (default: 1)
       loop     => 4, # loop limit if finite (default: 1)
@@ -155,6 +156,21 @@ version 0.0105
 
 C<MIDI::RtMidi::ScorePlayer> plays a MIDI score in real-time.
 
+=head2 Hints
+
+B<Linux>: Timidity support requires timidity in daemon mode If your
+distro does not install a service, do: C<timidity -iAD>. Also,
+FluidSynth is an alternative to Timidity++
+
+B<MacOS>: You can get General MIDI via DLSMusicDevice within Logic or
+Garageband. You will need a soundfont containing drum patches in
+'~/Library/Audio/Sounds/Banks/' and DLSMusicDevice open in Garageband
+or Logic with this sound front selected. DLSMusicDevice should receive
+input from the virtual port opened below. See L<MIDI::RtMidi::FFI::Device>
+docs for more info. Alternatively you can use FluidSynth, like
+C<fluidsynth -a coreaudio -m coremidi -g 1.0 ~/Music/some-soundfont.sf2>.
+Also, you can use C<timidity> too.
+
 =head1 METHODS
 
 =head2 new
@@ -167,9 +183,7 @@ Play a given MIDI score in real-time.
 
 =head1 SEE ALSO
 
-The informative comments in the source of this module!
-
-The F<eg/*> files in this distribution.
+Examples can be found in the F<eg/*> files in this distribution.
 
 L<MIDI::RtMidi::FFI::Device>
 
